'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

require('./wunderbar.css');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Wunderbar = function Wunderbar(props) {
    var x = props.x;
    var y = props.y;
    var width = props.width;
    var interval = props.width / (props.max - props.min);
    var ticks = width / interval;
    var height = props.height;
    var majorTick = props.majorTick;
    var majorTicks = width / majorTick;
    // const pointer = (currentPoint) =>  [currentPoint * interval,20,currentPoint * interval,0,(currentPoint * interval) + (2 * interval),0];
    var pointer = function pointer(currentPoint, height) {
        var x1 = (currentPoint - props.min) * interval - interval / 2;
        var y1 = 0;
        var x2 = x1 + interval;
        var y2 = 0;
        var x3 = x1 + interval / 2;
        var y3 = height / 2;
        return [x1, y1, x2, y2, x3, y3];
    };
    var highlightRegion = props.highlightRegion;
    var scaleFill = props.scaleFill;
    var majorTickStroke = props.majorTickStroke;
    var minorTickStroke = props.minorTickStroke;
    var highlightFill = props.highlightFill;
    var pointerStroke = props.pointerStroke;
    var pointsOfInterest = props.pointsOfInterest || [];
    var MTT = [];
    for (var i = props.min; i <= props.max; i += majorTick) {
        MTT.push(i);
    }
    return _react2.default.createElement(
        'svg',
        { x: x, y: y, height: height + 50, width: width + 50 },
        _react2.default.createElement(
            'g',
            null,
            _react2.default.createElement('rect', { width: width, height: height, fill: scaleFill }),
            highlightRegion && highlightRegion.length == 2 && _react2.default.createElement('rect', { x: (highlightRegion[0] - props.min) * interval, y: height / 2, width: (highlightRegion[1] - highlightRegion[0]) * interval, height: height / 2, fill: highlightFill, opacity: '0.25' }),
            Array(ticks).fill(0).map(function (r, i) {
                return _react2.default.createElement('line', { key: "LINE" + i, x1: i * interval, y1: height / (i % majorTick == 0 ? 2 : 1.5), x2: i * interval, y2: height, stroke: i % majorTick == 0 ? majorTickStroke : minorTickStroke, strokeWidth: i % majorTick == 0 ? 2 : 1 });
            }),
            _react2.default.createElement('polygon', { points: pointer(props.currentPoint, height), fill: pointerStroke }),
            MTT.map(function (v, x) {
                return _react2.default.createElement(
                    'text',
                    { key: "MT" + x, x: x * majorTick * interval, y: height / 2, fill: props.tickFill },
                    props.majorTickFormatter(v)
                );
            }),
            pointsOfInterest && pointsOfInterest.map(function (poi) {
                return poi.points.map(function (pt, i) {
                    return _react2.default.createElement('circle', { cx: (pt - props.min) * interval, cy: height / 1.5, r: '2', fill: poi.colour, title: poi.title, key: poi.title + i });
                });
            })
        )
    );
};

Wunderbar.defaultProps = {
    x: 0,
    y: 0,
    width: 600,
    height: 50,
    min: 0,
    max: 100,
    majorTick: 50,
    currentPoint: 0,
    scaleFill: "#C89B7B",
    majorTickStroke: "#80475E",
    minorTickStroke: "#111D13",
    highlightFill: "#F0F757",
    pointerStroke: "#34344A",
    tickFill: "white",
    majorTickFormatter: function majorTickFormatter(v) {
        return v;
    }
};

Wunderbar.propTypes = {
    x: _propTypes2.default.number,
    y: _propTypes2.default.number,
    width: _propTypes2.default.number,
    height: _propTypes2.default.number,
    min: _propTypes2.default.number,
    max: _propTypes2.default.number,
    majorTick: _propTypes2.default.number,
    currentPoint: _propTypes2.default.number,
    majorTickStroke: _propTypes2.default.string,
    minorTickStroke: _propTypes2.default.string,
    highlightFill: _propTypes2.default.string,
    pointerStroke: _propTypes2.default.string,
    tickFill: _propTypes2.default.string
};

exports.default = Wunderbar;